@@ -1,13 +1,16 @@
-import httplib
-import six
+try:
+    import httplib  # Python 2
+except ImportError:
+    import http.client as httplib  # Python 3
 
-from exceptions import QuickbooksException, SevereException
+from .exceptions import QuickbooksException, SevereException
 
 try:
     from rauth import OAuth1Session, OAuth1Service
 except ImportError:
     print("Please import Rauth:\n\n")
     print("http://rauth.readthedocs.org/en/latest/\n")
+    raise
 
 
 class QuickBooks(object):
@@ -166,7 +169,7 @@ class QuickBooks(object):
         try:
             result = req.json()
         except:
-            raise QuickbooksException("Error reading json response", 10000, "")
+            raise QuickbooksException("Error reading json response", 10000)
 
         if req.status_code is not httplib.OK or "Fault" in result:
             self.handle_exceptions(result["Fault"])
