@@ -1,15 +1,18 @@
 import simplejson as json
-from utils import build_where_clause
-from client import QuickBooks
+from .utils import build_where_clause
+from .client import QuickBooks
+
 
 class ToJsonMixin(object):
     def to_json(self):
         return json.dumps(self, default=self.json_filter(), sort_keys=True, indent=4)
 
     def json_filter(self):
-        # filter out properties that have names starting with _ or properties that have a value of None
-        return lambda obj: {k: v for k, v in obj.__dict__.items()
-                                   if not k.startswith('_') and getattr(obj, k) is not None}
+        """
+        filter out properties that have names starting with _ or properties that have a value of None
+        """
+        return lambda obj: dict((k, v) for k, v in obj.__dict__.items()
+                                if not k.startswith('_') and getattr(obj, k) is not None)
 
 
 class FromJsonMixin(object):
@@ -44,7 +47,6 @@ class ReadMixin(object):
 
     @classmethod
     def get(cls, id):
-        from client import QuickBooks
         qb = QuickBooks()
 
         json_data = qb.get_single_object(cls.qbo_object_name, pk=id)
@@ -55,10 +57,9 @@ class UpdateMixin(object):
     qbo_object_name = ""
 
     def save(self):
-        from .client import QuickBooks
         qb = QuickBooks()
 
-        if self.Id > 0:
+        if self.Id and self.Id > 0:
             json_data = qb.update_object(self.qbo_object_name, self.to_json())
         else:
             json_data = qb.create_object(self.qbo_object_name, self.to_json())
