@@ -1,6 +1,8 @@
-from base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
+from six import python_2_unicode_compatible
+from .base import Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
 
 
+@python_2_unicode_compatible
 class Account(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: Account is a component of a Chart Of Accounts, and is part of a Ledger. Used to record a total
@@ -12,6 +14,8 @@ class Account(QuickbooksManagedObject, QuickbooksTransactionEntity):
 
     class_dict = {
         "CurrencyRef": Ref,
+        "ParentRef": Ref,
+        "TaxCodeRef": Ref,
     }
 
     qbo_object_name = "Account"
@@ -26,11 +30,15 @@ class Account(QuickbooksManagedObject, QuickbooksTransactionEntity):
         self.Classification = ""
         self.AccountType = ""
         self.AccountSubType = ""
+        self.Description = ""
+        self.AcctNum = ""
         self.CurrentBalance = 0
         self.CurrentBalanceWithSubAccounts = 0
         self.CurrencyRef = None
+        self.ParentRef = None
+        self.TaxCodeRef = None
 
-    def __unicode__(self):
+    def __str__(self):
         return self.FullyQualifiedName
 
     def to_ref(self):
