@@ -8,7 +8,7 @@ class SalesItemLineDetailTests(unittest.TestCase):
         detail = SalesItemLineDetail()
         detail.UnitPrice = 10
 
-        self.assertEquals(unicode(detail), "10")
+        self.assertEquals(str(detail), "10")
 
 
 class CreditMemoLineTests(unittest.TestCase):
@@ -18,7 +18,7 @@ class CreditMemoLineTests(unittest.TestCase):
         memo_line.Description = "Product Description"
         memo_line.Amount = 100
 
-        self.assertEquals(unicode(memo_line), "[1] Product Description 100")
+        self.assertEquals(str(memo_line), "[1] Product Description 100")
 
 
 class CreditMemoTests(unittest.TestCase):
@@ -26,7 +26,7 @@ class CreditMemoTests(unittest.TestCase):
         credit_memo = CreditMemo()
         credit_memo.TotalAmt = 1000
 
-        self.assertEquals(unicode(credit_memo), "1000")
+        self.assertEquals(str(credit_memo), "1000")
 
 
 class DiscountLineDetailTests(unittest.TestCase):
